@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2022 Losant IoT, Inc.
+Copyright (c) 2023 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -58,7 +58,7 @@ class ApplicationApiTokens(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - Collection of API tokens (https://api.losant.com/#/definitions/apiToken)
+        *  200 - Collection of API tokens (https://api.losant.com/#/definitions/apiTokens)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
