@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2022 Losant IoT, Inc.
+Copyright (c) 2023 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -191,7 +191,7 @@ class Dashboard(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - Send dashboard report (https://api.losant.com/#/definitions/success)
+        *  202 - If dashboard report was enqueued to be sent (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
@@ -231,6 +231,8 @@ class Dashboard(object):
         *  {string} dashboardId - ID of the associated dashboard
         *  {hash} ctx - The context object to validate (https://api.losant.com/#/definitions/dashboardContextInstance)
         *  {string} password - Password for password-protected dashboards
+        *  {string} duration - Duration of data to fetch in milliseconds
+        *  {string} resolution - Resolution in milliseconds
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -255,6 +257,10 @@ class Dashboard(object):
             body = kwargs["ctx"]
         if "password" in kwargs:
             query_params["password"] = kwargs["password"]
+        if "duration" in kwargs:
+            query_params["duration"] = kwargs["duration"]
+        if "resolution" in kwargs:
+            query_params["resolution"] = kwargs["resolution"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
