@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2022 Losant IoT, Inc.
+Copyright (c) 2023 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -106,7 +106,7 @@ class Device(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - If generation of export was successfully started (https://api.losant.com/#/definitions/success)
+        *  202 - If generation of export was successfully started (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
@@ -159,8 +159,8 @@ class Device(object):
         *  {string} applicationId - ID associated with the application
         *  {string} deviceId - ID associated with the device
         *  {string} excludeConnectionInfo - If set, do not return connection info
-        *  {string} tagsAsObject - Return tags as an object map instead of an array.
-        *  {string} attributesAsObject - Return attributes as an object map instead of an array.
+        *  {string} tagsAsObject - Return tags as an object map instead of an array
+        *  {string} attributesAsObject - Return attributes as an object map instead of an array
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -444,8 +444,8 @@ class Device(object):
         *  {string} applicationId - ID associated with the application
         *  {string} deviceId - ID associated with the device
         *  {hash} device - Object containing new properties of the device (https://api.losant.com/#/definitions/devicePatch)
-        *  {string} tagsAsObject - Return tags as an object map instead of an array.
-        *  {string} attributesAsObject - Return attributes as an object map instead of an array.
+        *  {string} tagsAsObject - Return tags as an object map instead of an array
+        *  {string} attributesAsObject - Return attributes as an object map instead of an array
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -562,7 +562,7 @@ class Device(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - If data removal was successfully started (https://api.losant.com/#/definitions/success)
+        *  202 - If data removal was successfully started (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
