@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2022 Losant IoT, Inc.
+Copyright (c) 2023 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -55,7 +55,7 @@ class DeviceRecipe(object):
 
         Responses:
         *  201 - If devices were successfully created (https://api.losant.com/#/definitions/deviceRecipeBulkCreate)
-        *  202 - If devices were enqueued to be created (https://api.losant.com/#/definitions/deviceRecipeBulkCreateEnqueued)
+        *  202 - If devices were enqueued to be created (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
@@ -147,6 +147,8 @@ class DeviceRecipe(object):
         Parameters:
         *  {string} applicationId - ID associated with the application
         *  {string} deviceRecipeId - ID associated with the device recipe
+        *  {string} tagsAsObject - Return tags as an object map instead of an array
+        *  {string} attributesAsObject - Return attributes as an object map instead of an array
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -169,6 +171,10 @@ class DeviceRecipe(object):
             path_params["applicationId"] = kwargs["applicationId"]
         if "deviceRecipeId" in kwargs:
             path_params["deviceRecipeId"] = kwargs["deviceRecipeId"]
+        if "tagsAsObject" in kwargs:
+            query_params["tagsAsObject"] = kwargs["tagsAsObject"]
+        if "attributesAsObject" in kwargs:
+            query_params["attributesAsObject"] = kwargs["attributesAsObject"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
@@ -196,6 +202,8 @@ class DeviceRecipe(object):
         *  {string} applicationId - ID associated with the application
         *  {string} deviceRecipeId - ID associated with the device recipe
         *  {hash} deviceRecipe - Object containing new properties of the device recipe (https://api.losant.com/#/definitions/deviceRecipePatch)
+        *  {string} tagsAsObject - Return tags as an object map instead of an array
+        *  {string} attributesAsObject - Return attributes as an object map instead of an array
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -220,6 +228,10 @@ class DeviceRecipe(object):
             path_params["deviceRecipeId"] = kwargs["deviceRecipeId"]
         if "deviceRecipe" in kwargs:
             body = kwargs["deviceRecipe"]
+        if "tagsAsObject" in kwargs:
+            query_params["tagsAsObject"] = kwargs["tagsAsObject"]
+        if "attributesAsObject" in kwargs:
+            query_params["attributesAsObject"] = kwargs["attributesAsObject"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
