@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2022 Losant IoT, Inc.
+Copyright (c) 2023 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -209,7 +209,7 @@ class Devices(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - If generation of export was successfully started (https://api.losant.com/#/definitions/success)
+        *  202 - If generation of export was successfully started (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
@@ -265,8 +265,8 @@ class Devices(object):
         *  {string} excludeConnectionInfo - If set, do not return connection info
         *  {string} parentId - Filter devices as children of a given system id
         *  {hash} query - Device filter JSON object which overrides the filterField, filter, deviceClass, tagFilter, and parentId parameters. (https://api.losant.com/#/definitions/advancedDeviceQuery)
-        *  {string} tagsAsObject - Return tags as an object map instead of an array.
-        *  {string} attributesAsObject - Return attributes as an object map instead of an array.
+        *  {string} tagsAsObject - Return tags as an object map instead of an array
+        *  {string} attributesAsObject - Return attributes as an object map instead of an array
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -394,7 +394,7 @@ class Devices(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - If generation of export was successfully started (https://api.losant.com/#/definitions/success)
+        *  202 - If generation of export was successfully started (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
@@ -436,8 +436,8 @@ class Devices(object):
         Parameters:
         *  {string} applicationId - ID associated with the application
         *  {hash} device - New device information (https://api.losant.com/#/definitions/devicePost)
-        *  {string} tagsAsObject - Return tags as an object map instead of an array.
-        *  {string} attributesAsObject - Return attributes as an object map instead of an array.
+        *  {string} tagsAsObject - Return tags as an object map instead of an array
+        *  {string} attributesAsObject - Return attributes as an object map instead of an array
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -546,6 +546,7 @@ class Devices(object):
 
         Responses:
         *  200 - If command was successfully sent (https://api.losant.com/#/definitions/success)
+        *  202 - If command was queued to be sent (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
