@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2022 Losant IoT, Inc.
+Copyright (c) 2023 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -101,7 +101,7 @@ class Events(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - If generation of export was successfully started (https://api.losant.com/#/definitions/success)
+        *  202 - If generation of export was successfully started (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
@@ -219,7 +219,7 @@ class Events(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - The event, plus count of currently new events
+        *  200 - The event, plus count of currently new events (https://api.losant.com/#/definitions/eventPlusNewCount)
 
         Errors:
         *  404 - Error if application was not found (https://api.losant.com/#/definitions/error)
@@ -272,7 +272,8 @@ class Events(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - If the bulk update has been successfully started (https://api.losant.com/#/definitions/success)
+        *  200 - If the bulk update has been completed (https://api.losant.com/#/definitions/success)
+        *  202 - If a bulk update job has been enqueued (https://api.losant.com/#/definitions/jobEnqueuedResult)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
